package com.sun.org.apache.bcel.internal.generic;

import com.sun.org.apache.bcel.internal.classfile.ConstantUtf8;
import java.io.IOException;
import java.io.DataOutputStream;
import com.sun.org.apache.bcel.internal.classfile.ElementValue;
import com.sun.org.apache.bcel.internal.classfile.ElementValuePair;

public class ElementValuePairGen
{
    private int nameIdx;
    private final ElementValueGen value;
    private final ConstantPoolGen cpool;
    
    public ElementValuePairGen(ElementValuePair nvp, ConstantPoolGen cpool, boolean copyPoolEntries) {
        this.cpool = cpool;
        if (copyPoolEntries) {
            this.nameIdx = cpool.addUtf8(nvp.getNameString());
        }
        else {
            this.nameIdx = nvp.getNameIndex();
        }
        this.value = ElementValueGen.copy(nvp.getValue(), cpool, copyPoolEntries);
    }
    
    public ElementValuePair getElementNameValuePair() {
        ElementValue immutableValue = this.value.getElementValue();
        return new ElementValuePair(this.nameIdx, immutableValue, this.cpool.getConstantPool());
    }
    
    protected ElementValuePairGen(int idx, ElementValueGen value, ConstantPoolGen cpool) {
        this.nameIdx = idx;
        this.value = value;
        this.cpool = cpool;
    }
    
    public ElementValuePairGen(String name, ElementValueGen value, ConstantPoolGen cpool) {
        this.nameIdx = cpool.addUtf8(name);
        this.value = value;
        this.cpool = cpool;
    }
    
    protected void dump(DataOutputStream dos) throws IOException {
        dos.writeShort(this.nameIdx);
        this.value.dump(dos);
    }
    
    public int getNameIndex() {
        return this.nameIdx;
    }
    
    public final String getNameString() {
        return ((ConstantUtf8)this.cpool.getConstant(this.nameIdx)).getBytes();
    }
    
    public final ElementValueGen getValue() {
        return this.value;
    }
    
    @Override
    public String toString() {
        return "ElementValuePair:[" + this.getNameString() + "=" + this.value.stringifyValue() + "]";
    }
}
